package Chart::Clicker::Axis::DivisionType;
$Chart::Clicker::Axis::DivisionType::VERSION = '2.90';
use Moose::Role;
requires qw{range ticks};

no Moose;

1;

__END__

=pod

=head1 NAME

Chart::Clicker::Axis::DivisionType

=head1 VERSION

version 2.90

=head1 DESCRIPTION

=head1 NAME

Chart::Clicker::Axis::DivisionType - Division style for ticks

=head1 AUTHOR

Rod Taylor <chartclicker@rbt.ca>

=head1 SEE ALSO

perl(1)

=head1 LICENSE

You can redistribute and/or modify this code under the same terms as Perl
itself.

=head1 AUTHOR

Cory G Watson <gphat@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2016 by Cory G Watson.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
